@@ -1,9 +1,6 @@
 from __future__ import annotations
 
 from django.apps import AppConfig
-from django.conf import settings
-
-from django_spire.consts import AI_CHAT_WORKFLOW_CLASS_SETTINGS_NAME
 from django_spire.utils import check_required_apps
 
 
@@ -20,11 +17,7 @@ class AiChatConfig(AppConfig):
         },
     )
 
-    REQUIRED_APPS = ('django_spire_ai',)
+    REQUIRED_APPS = ('django_spire_ai', 'django_spire_ai_context')
 
     def ready(self) -> None:
-        if not isinstance(getattr(settings, AI_CHAT_WORKFLOW_CLASS_SETTINGS_NAME), str):
-            message = f'"{AI_CHAT_WORKFLOW_CLASS_SETTINGS_NAME}" must be set in the django settings when using "{self.label}".'
-            raise TypeError(message)
-
         check_required_apps(self.label)
