@@ -1,15 +1,17 @@
+from __future__ import annotations
+
 from django_spire.ai.chat.tests.test_urls.factories import create_test_chat
 from django_spire.core.tests.test_cases import BaseTestCase
 from django.urls import reverse
 
 
 class ChatJsonUrlTests(BaseTestCase):
-    def setUp(self):
+    def setUp(self) -> None:
         super().setUp()
 
         self.test_chat = create_test_chat(user=self.super_user)
 
-    def test_delete_view_url_path(self):
+    def test_delete_view_url_path(self) -> None:
         response = self.client.post(
             reverse(
                 'django_spire:ai:chat:json:delete',
@@ -18,4 +20,4 @@ class ChatJsonUrlTests(BaseTestCase):
             content_type='application/json'
         )
 
-        self.assertEqual(response.status_code, 200)
+        assert response.status_code == 200
