@@ -6,5 +6,5 @@ urlpatterns = [
     path('json/', include('django_spire.ai.chat.urls.json_urls', namespace='json')),
     path('message/', include('django_spire.ai.chat.urls.message_urls', namespace='message')),
     path('page/', include('django_spire.ai.chat.urls.page_urls', namespace='page')),
-    path('template/', include('django_spire.ai.chat.urls.template_urls', namespace='template')),
+    path('template/', include('django_spire.ai.chat.urls.template.template_urls', namespace='template')),
 ]
