@@ -6,5 +6,5 @@ from django_spire.ai.chat.views import page_views
 app_name = 'page'
 
 urlpatterns = [
-    path('home/', page_views.home_view, name='home'),
+    path('home/', page_views.chat_view, name='home'),
 ]
