@@ -1,12 +1,17 @@
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from django.http import HttpResponse
 
 from django_spire.ai.chat.models import Chat
 from django_spire.ai.chat.responses import MessageResponseGroup
 
+if TYPE_CHECKING:
+    from django.core.handlers.wsgi import WSGIRequest
 
-def load_messages_render_view(request, chat_id):
+
+def load_messages_render_view(request: WSGIRequest, chat_id: int) -> HttpResponse:
     chat = (
         Chat.objects
         .by_user(request.user)
@@ -24,6 +29,7 @@ def load_messages_render_view(request, chat_id):
         message_group.render_to_html_string(
             {
                 'chat_id': chat.id,
+                'is_loading': True,
             }
         )
     )
