@@ -1,4 +1,6 @@
-from dandy.recorder import Recorder
+from __future__ import annotations
+
+from dandy import Recorder
 
 from django_spire.ai.prompt.bots import DandyPythonPromptBot
 from django_spire.ai.prompt.tuning.bots import SimplePromptTuningBot
@@ -7,8 +9,8 @@ from django_spire.ai.prompt.tuning.bots import SimplePromptTuningBot
 def prompt_tuning_cli(prompt: str):
     Recorder.start_recording(recording_name='prompt_tuning')
 
-    # ENTER YOUR PROMPT HERE!
     holding = prompt
+    tuning_bot = SimplePromptTuningBot()
 
     print('----------------------------------------------------')
 
@@ -21,10 +23,7 @@ def prompt_tuning_cli(prompt: str):
 
         print('Attempting to tune prompt.....')
 
-        new_prompt = (
-            SimplePromptTuningBot()
-            .process(holding, feedback)
-        )
+        new_prompt = tuning_bot.process(holding, feedback)
         holding = new_prompt.prompt
 
         print('----------------------NEW PROMPT START------------------------------')
@@ -34,7 +33,8 @@ def prompt_tuning_cli(prompt: str):
         print('----------------------NEW PROMPT END------------------------------')
         print()
 
-
     Recorder.stop_recording(recording_name='prompt_tuning')
     Recorder.to_html_file(recording_name='prompt_tuning')
-    DandyPythonPromptBot().process(prompt)
+
+    python_bot = DandyPythonPromptBot()
+    python_bot.process(prompt)
