@@ -3,11 +3,14 @@ from __future__ import annotations
 from django.contrib.auth.models import User
 from django.urls import reverse
 
+from django_spire.auth.user.services.services import AuthUserService
 from django_spire.contrib import Breadcrumbs
 from django_spire.history.activity.mixins import ActivityMixin
 
 
 class AuthUser(User, ActivityMixin):
+    services = AuthUserService()
+
     @classmethod
     def base_breadcrumb(cls) -> Breadcrumbs:
         crumbs = Breadcrumbs()
@@ -21,7 +24,7 @@ class AuthUser(User, ActivityMixin):
         if self.pk:
             crumbs.add_breadcrumb(
                 name=self.get_full_name(),
-                href=reverse('django_spire:auth:user:detail', kwargs={'pk': self.pk})
+                href=reverse('django_spire:auth:user:page:detail', kwargs={'pk': self.pk})
             )
 
         return crumbs
