@@ -4,6 +4,7 @@ import tempfile
 
 from django.test import Client, override_settings, TestCase
 
+from django_spire.auth.user.models import AuthUser
 from django_spire.auth.user.tests.factories import create_super_user
 
 
@@ -15,5 +16,7 @@ class BaseTestCase(TestCase):
     def setUp(self) -> None:
         self.client = Client()
 
-        self.super_user = create_super_user()
+        self.super_user = AuthUser.objects.create_superuser(
+            username='stratus',
+        )
         self.client.force_login(self.super_user)
