@@ -3,14 +3,21 @@ from __future__ import annotations
 from django.db import models
 
 from django_spire.auth.group.models import AuthGroup
+from django_spire.contrib import Breadcrumbs
 from django_spire.contrib.ordering.mixins import OrderingModelMixin
+from django_spire.core.tag.mixins import TagModelMixin
+from django_spire.contrib.utils import truncate_string
 from django_spire.history.mixins import HistoryModelMixin
 from django_spire.knowledge.collection.querysets import CollectionQuerySet
 from django_spire.knowledge.collection.services.service import CollectionGroupService, \
     CollectionService
 
 
-class Collection(HistoryModelMixin, OrderingModelMixin):
+class Collection(
+    HistoryModelMixin,
+    OrderingModelMixin,
+    TagModelMixin,
+):
     parent = models.ForeignKey(
         'self',
         on_delete=models.CASCADE,
@@ -29,6 +36,24 @@ class Collection(HistoryModelMixin, OrderingModelMixin):
     def __str__(self):
         return self.name
 
+    @property
+    def name_short(self) -> str:
+        return truncate_string(self.name, 32)
+
+    @property
+    def top_level_parent(self) -> Collection:
+        if self.parent is None:
+            return self
+
+        return self.parent.top_level_parent
+
+    def base_breadcrumb(self) -> Breadcrumbs:
+        breadcrumbs = Breadcrumbs()
+
+        breadcrumbs.add_breadcrumb(self.name_short)
+
+        return breadcrumbs
+
     class Meta:
         verbose_name = 'Collection'
         verbose_name_plural = 'Collections'
@@ -37,6 +62,7 @@ class Collection(HistoryModelMixin, OrderingModelMixin):
             ('can_access_all_collections', 'Can Access All Collections'),
             ('can_change_collection_groups', 'Can Change Collection Groups'),
         ]
+        ordering = ['name']
 
 
 class CollectionGroup(models.Model):
@@ -55,3 +81,6 @@ class CollectionGroup(models.Model):
     )
 
     services = CollectionGroupService()
+
+    def __str__(self):
+        return f'{self.collection.name} - {self.auth_group.name}'
