@@ -6,7 +6,7 @@ from typing import TYPE_CHECKING
 
 from markitdown import MarkItDown
 
-from django_spire.knowledge.entry.version.constants import MARKDOWN_AI_CHUNK_SIZE
+from django_spire.knowledge.entry.version.consts import MARKDOWN_AI_CHUNK_SIZE
 from django_spire.knowledge.entry.version.converters.converter import \
     BaseConverter
 from django_spire.knowledge.entry.version.block import models
@@ -44,13 +44,11 @@ class DocxConverter(BaseConverter):
             for i in range(0, len(markdown_content), MARKDOWN_AI_CHUNK_SIZE)
         ]
 
-        markdown_format_bot = MarkdownFormatLlmBot()
-
         with ThreadPoolExecutor(max_workers=4) as executor:
             futures = []
             for idx, chunk in enumerate(markdown_content_chunks):
                 future = executor.submit(
-                    markdown_format_bot.process,
+                    MarkdownFormatLlmBot().process,
                     markdown_content=chunk
                 )
                 future.index = idx
