@@ -6,5 +6,5 @@ from django_spire.knowledge.entry.version.views import page_views
 app_name = 'page'
 
 urlpatterns = [
-    path('<int:pk>/detail/', page_views.detail_view, name='detail'),
+    path('<int:pk>/editor/', page_views.editor_view, name='editor'),
 ]
