@@ -3,6 +3,7 @@ from __future__ import annotations
 from django.conf import settings
 from django.core.mail import EmailMessage
 
+from django_spire.file.models import File
 from django_spire.notification.models import Notification
 
 
@@ -27,6 +28,11 @@ class EmailHelper:
         self.from_email = settings.DEFAULT_FROM_EMAIL
         self.fail_silently = fail_silently
 
+        self.attachments = []
+        for attachment in list(email.attachments.all()):
+            with attachment.file.open('rb') as f:
+                self.attachments.append((attachment.name, f.read(), attachment.type))
+
 
 class SendGridEmailHelper(EmailHelper):
     def __init__(
@@ -58,7 +64,9 @@ class SendGridEmailHelper(EmailHelper):
             to=self.to,
             cc=self.cc,
             bcc=self.bcc,
+            attachments=self.attachments
         )
+
         msg.template_id = self.template_id
         msg.dynamic_template_data = self.template_data
         msg.send(fail_silently=self.fail_silently)
