@@ -7,15 +7,12 @@ class ThemeFamily(StrEnum):
     AYU = 'ayu'
     CATPPUCCIN = 'catppuccin'
     DEFAULT = 'default'
-    DRACULA = 'dracula'
     GRUVBOX = 'gruvbox'
     MATERIAL = 'material'
     NORD = 'nord'
-    OCEANIC_NEXT = 'oceanic-next'
     ONE_DARK = 'one-dark'
     PALENIGHT = 'palenight'
     ROSE_PINE = 'rose-pine'
-    SYNTHWAVE = 'synthwave'
     TOKYO_NIGHT = 'tokyo-night'
 
 
